@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import secrets
 import shutil
 import subprocess
@@ -5,18 +7,47 @@ from enum import Enum
 from pathlib import Path
 
 import typer
+from dict_deep import deep_set
 from rich import print as rich_print
 from rich.progress import Progress
 from rich.progress import SpinnerColumn
 from rich.progress import TextColumn
 
 from ..utils import clean_project_name
+from ..utils import read_toml
+from ..utils import RICH_ERROR_MARKER
 from ..utils import RICH_INFO_MARKER
 from ..utils import RICH_SUCCESS_MARKER
+from ..utils import write_toml
 
 __all__ = ["make_project"]
 
 
+def _get_user_git_infos() -> tuple[str, str] | None:
+    git_config_cmd = ["git", "config", "--global", "--get"]
+    try:
+        user_name_cmd = subprocess.run(
+            git_config_cmd + ["user.name"], capture_output=True, text=True
+        )
+        user_email_cmd = subprocess.run(
+            git_config_cmd + ["user.email"], capture_output=True, text=True
+        )
+    except FileNotFoundError:
+        return None
+    if user_email_cmd.returncode != 0 or user_email_cmd.returncode != 0:
+        return None
+    return (
+        user_name_cmd.stdout.strip("\n"),
+        user_email_cmd.stdout.strip("\n"),
+    )
+
+
+def _set_authors_in_pyproject(file: Path, name: str, email: str) -> None:
+    config = read_toml(file)
+    deep_set(config, "tool.poetry.authors", [f"{name} <{email}>"])
+    write_toml(file, config)
+
+
 class Branch(str, Enum):
     main = "main"
     tailwind = "tailwind"
@@ -38,6 +69,13 @@ def make_project(
 ):
     """Initialize a new django project."""
 
+    if Path(project_name).exists():
+        rich_print(
+            f"{RICH_ERROR_MARKER} A directory with the name {project_name} already exists in the current directory "
+            f":disappointed_face:"
+        )
+        raise typer.Abort()
+
     with Progress(
         SpinnerColumn(),
         TextColumn("[progress.description]{task.description}"),
@@ -84,4 +122,15 @@ def make_project(
         f"https://github.com/Tobi-De/fuzzy-couscous"
     )
 
+    user_infos = _get_user_git_infos()
+    if user_infos:
+        name, email = user_infos
+        _set_authors_in_pyproject(
+            new_project_dir / "pyproject.toml", name=name, email=email
+        )
+        msg += (
+            f"\n{RICH_INFO_MARKER} A git global user configuration was found and used to update the authors in your "
+            f"pyproject.toml file."
+        )
+
     rich_print(msg)
